|    filepath     |     function      | passed | skipped | xpassed | SUBTOTAL |
| --------------- | ----------------- | -----: | ------: | ------: | -------: |
| test_pass.py    | test_pass         |      1 |       0 |       0 |        1 |
| test_pass.py    | Test.test_pass    |      1 |       0 |       0 |        1 |
| test_skipped.py | test_skipped      |      0 |       1 |       0 |        1 |
| test_skipped.py | Test.test_skipped |      0 |       1 |       0 |        1 |
| test_xpassed.py | test_xpassed      |      0 |       0 |       1 |        1 |
| test_xpassed.py | Test.test_xpassed |      0 |       0 |       1 |        1 |
| TOTAL           |                   |      2 |       2 |       2 |       12 |
